@@ -1,7 +1,11 @@
 """Analyzer module, implementing facilities for analyzing circuits using Classiq platform."""
+import webbrowser
+
 from classiq import api_wrapper
+from classiq import client
 from classiq_interface.analyzer import result as analysis_result, analysis_params
 from classiq_interface.generator import result as generator_result
+from classiq_interface.server import routes
 
 
 class Analyzer:
@@ -27,4 +31,11 @@ class Analyzer:
         if result.status != analysis_result.AnalysisStatus.SUCCESS:
             raise Exception(f"Analysis failed: {result.details}")
 
+        dashboard_path = routes.ANALYZER_DASHBOARD
+        self.run_external_app(path=dashboard_path)
         return result.details
+
+    @staticmethod
+    def run_external_app(path: str) -> None:
+        backend_uri = client.client().get_backend_uri()
+        webbrowser.open_new_tab(f"{backend_uri}{path}")
