@@ -27,7 +27,7 @@ class Generator:
             max_depth (): The maximum depth of the generated circuit.
         """
         self._constraints = constraints.QuantumCircuitConstraints(
-            qubits_count=qubit_count, max_depth=max_depth, **kwargs
+            qubit_count=qubit_count, max_depth=max_depth, **kwargs
         )
 
     async def generate(self) -> result.GeneratedCircuit:
